@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 # -T client threads (wrk -t)
 # -c connections per client thread
@@ -176,8 +176,7 @@ StartPuma()
   if [ -n "$1" ]; then
     rackup_file=$1
   fi
-
-  echo "Branch: $(git branch --show-current)"
+  export PUMA_RU_FILE=$rackup_file
 
   printf "\nbundle exec puma -q -b $bind $puma_args --control-url=tcp://$PUMA_CTRL --control-token=test $rackup_file\n\n"
   bundle exec puma -q -b $bind $puma_args --control-url=tcp://$PUMA_CTRL --control-token=test $rackup_file &
